"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.config = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const tsconfig_1 = require("./tsconfig");
const vitest_1 = require("./vitest");
const prettier_1 = require("./prettier");
const eslint_1 = require("./eslint");
const commitlint_1 = require("./commitlint");
const has_package_1 = require("./has-package");
const baseConfig = {
    '.eslintignore': fs_1.default.readFileSync(path_1.default.resolve(__dirname, '../templates/eslintignore'), 'utf8'),
    '.npmignore': fs_1.default.readFileSync(path_1.default.resolve(__dirname, '../templates/npmignore'), 'utf8'),
    'tsconfig.json': { configuration: tsconfig_1.tsconfig, stringify: true },
    'tsconfig.build.json': { configuration: tsconfig_1.tsconfigBuild, stringify: true },
    '.prettierrc.js': { configuration: prettier_1.prettierConfig },
    '.eslintrc.js': { configuration: eslint_1.eslintRc },
    '.commitlintrc.json': { configuration: commitlint_1.commitLint, stringify: true },
};
if ((0, has_package_1.hasPackage)('vitest')) {
    Object.assign(baseConfig, {
        'vitest.config.ts': { configuration: vitest_1.vitestConfig },
    });
}
try {
    const { type } = JSON.parse(fs_1.default.readFileSync('package.json', 'utf8'));
    if (type === 'module') {
        baseConfig['.eslintrc.cjs'] = baseConfig['.eslintrc.js'];
        delete baseConfig['.eslintrc.js'];
        baseConfig['.prettierrc.cjs'] = baseConfig['.prettierrc.js'];
        delete baseConfig['.prettierrc.js'];
        eslint_1.eslintRc.settings = {
            'import/resolver': {
                typescript: {}, // this loads <rootdir>/tsconfig.json to eslint
            },
            'import/parsers': {
                '@typescript-eslint/parser': ['.ts', '.tsx'],
            },
        };
        tsconfig_1.tsconfig.compilerOptions.module = 'Node16';
        tsconfig_1.tsconfig.compilerOptions.moduleResolution = 'node16';
    }
}
catch {
    // Do nothing
}
exports.config = baseConfig;
// eslint-disable-next-line import/no-default-export
exports.default = exports.config;
//# sourceMappingURL=index.js.map